@@ -18,7 +18,18 @@ function(filename){
     RIFF <- readChar(con, 4)
     file.length <- readBin(con, int, n = 1, size = 4)
     WAVE <- readChar(con, 4)
+    if (!(RIFF == "RIFF" && WAVE == "WAVE"))
+        warning("Looks like '", filename, "' is not a valid wave file.")
     FMT <- readChar(con, 4)
+    # waiting for the fmt chunk
+    i <- 0
+    while(FMT != "fmt "){
+        i <- i+1
+        belength <- readBin(con, int, n = 1, size = 4)
+        seek(con, where = belength, origin = "current")
+        FMT <- readChar(con, 4)
+        if(i > 5) stop("There seems to be no 'fmt ' chunk in this Wave (?) file.")
+    }
     fmt.length <- readBin(con, int, n = 1, size = 4)
     pcm <- readBin(con, int, n = 1, size = 2)
     channels <- readBin(con, int, n = 1, size = 2)
@@ -26,31 +37,24 @@ function(filename){
     bytes.second <- readBin(con, int, n = 1, size = 4)
     block.align <- readBin(con, int, n = 1, size = 2)
     bits <- readBin(con, int, n = 1, size = 2)
+    if(fmt.length > 16)
+        seek(con, where = fmt.length - 16, origin = "current")
     DATA <- readChar(con, 4)
+    # waiting for the data chunk    
+    i <- 0    
+    while(DATA != "data"){
+        i <- i+1
+        belength <- readBin(con, int, n = 1, size = 4)
+        seek(con, where = belength, origin = "current")
+        DATA <- readChar(con, 4)
+        if(i > 5) stop("There seems to be no 'data' chunk in this Wave (?) file.")
+    }
     data.length <- readBin(con, int, n = 1, size = 4)
-
-    bytes <- bits / 8
-    
-    # Checking header infos for validity:
-    if(!(RIFF == "RIFF" && WAVE == "WAVE" && FMT == "fmt " && 
-        (DATA == "data" || DATA == "PAD ") && fmt.length == 16 && pcm == 1))
-            warning("Looks like '", filename, "' is not a valid wave file.")
+    bytes <- bits/8
     if(((sample.rate * block.align) != bytes.second) || 
         ((channels * bytes) != block.align))
             warning("Wave file '", filename, "' seems to be corrupted.")
 
-    # Wild guess:
-    if(DATA == "PAD "){
-        N <- data.length / bytes
-        data.length <- file.length - 40 - data.length
-        pad <- readBin(con, int, n = N, size = bytes, signed = (bytes == 2))
-        if(any(pad)) stop("This is not a valid wave file.")
-        DATA <- readChar(con, 4)
-        if(DATA != "data")
-            warning("Looks like '", filename, "' is not a valid wave file.")
-    }
-        
-
     ## reading in sample data
     N <- data.length / bytes
     sample.data <- readBin(con, int, n = N, size = bytes, 
